@@ -1,14 +1,10 @@
-.First.lib <- function(libname, pkgname) {
+.onLoad <- function(libname, pkgname) {
     ## add our libs to the PATH
     if (.Platform$OS.type=="windows") {
-        .setenv <- if (exists("Sys.setenv")) Sys.setenv else Sys.putenv
         lp<-gsub("/","\\\\",paste(libname,pkgname,"libs",sep="/"))
         cp<-strsplit(Sys.getenv("PATH"),";")
-        if (! lp %in% cp) .setenv(PATH=paste(lp,Sys.getenv("PATH"),sep=";"))
+        if (! lp %in% cp) Sys.setenv(PATH=paste(lp,Sys.getenv("PATH"),sep=";"))
     }
     library.dynam("Cairo", pkgname, libname)
     .Call("Rcairo_initialize", PACKAGE="Cairo")
 }
-
-### in case we decide to keep the namespace ...
-.onLoad <- .First.lib
