@@ -409,12 +409,15 @@ static void CairoGD_Close(NewDevDesc *dd)
   CairoGDDesc *xd = (CairoGDDesc *) dd->deviceSpecific;
   if(!xd || !xd->cb) return;
   
+  xd->npages++;
   xd->cb->save_page(xd->cb,xd->npages);
-  if (xd->cb->onSave) {
+  if (xd->cb->onSave && xd->cb->onSave != R_NilValue) {
 	  SEXP devNr = PROTECT(ScalarInteger(ndevNumber(dd) + 1));
 	  SEXP pageNr = PROTECT(ScalarInteger(xd->npages + 1));
 	  eval(lang3(xd->cb->onSave, devNr, pageNr), R_GlobalEnv);
 	  UNPROTECT(2);
+	  R_ReleaseObject(xd->cb->onSave);
+	  xd->cb->onSave = 0;
   }
   xd->cb->destroy_backend(xd->cb);
 
